package com.sun.org.apache.xml.internal.security.utils;

import com.sun.org.slf4j.internal.LoggerFactory;
import com.sun.org.apache.xml.internal.security.algorithms.MessageDigestAlgorithm;
import com.sun.org.slf4j.internal.Logger;
import java.io.ByteArrayOutputStream;

public class DigesterOutputStream extends ByteArrayOutputStream
{
    private static final Logger LOG;
    final MessageDigestAlgorithm mda;
    
    public DigesterOutputStream(MessageDigestAlgorithm mda) {
        this.mda = mda;
    }
    
    @Override
    public void write(byte[] array) {
        this.write(array, 0, array.length);
    }
    
    @Override
    public void write(int n) {
        this.mda.update((byte)n);
    }
    
    @Override
    public void write(byte[] buf, int i, int n) {
        if (DigesterOutputStream.LOG.isDebugEnabled()) {
            DigesterOutputStream.LOG.debug("Pre-digested input:");
            StringBuilder sb = new StringBuilder(n);
            for (; i < i + n; ++i) {
                sb.append((char)buf[i]);
            }
            DigesterOutputStream.LOG.debug(sb.toString());
        }
        this.mda.update(buf, i, n);
    }
    
    public byte[] getDigestValue() {
        return this.mda.digest();
    }
    
    static {
        LOG = LoggerFactory.getLogger(DigesterOutputStream.class);
    }
}
